import csv

from django.contrib import admin
from django.http import HttpResponse

from .models import Account, Project, HonoraryCertificate, Library, IFG, Travel,\
                    Email, BusinessCard, List, Literature


def export_as_csv(self, request, queryset):

    meta = self.model._meta
    field_names = [field.name for field in meta.fields]

    response = HttpResponse(content_type='text/csv')
    response['Content-Disposition'] = 'attachment; filename={}.csv'.format(meta)
    writer = csv.writer(response)

    writer.writerow(field_names)
    for obj in queryset:
        row = writer.writerow([getattr(obj, field) for field in field_names])

    return response

export_as_csv.short_description = "Export Selected"

admin.site.add_action(export_as_csv)

@admin.register(Project)
class ProjectAdmin(admin.ModelAdmin):
    save_as = True
    search_fields = ('name', 'pid','finance_id', 'realname', 'start', 'end', 'participants_estimated', 'participants_real', 'cost', 'status')
    list_display = ('name', 'pid','finance_id', 'realname', 'start', 'end', 'participants_estimated', 'participants_real', 'cost', 'status')
    #    action = ['export_as_csv']
    date_hierarchy = 'start'

@admin.register(BusinessCard)
class BusinessCardAdmin(admin.ModelAdmin):
    save_as = True    
    search_fields = (('realname', 'service_id'), 'granted', 'granted_date', 'project')
    list_display = ('realname', 'service_id', 'granted', 'granted_date', 'project')
    list_display_links = ('realname', 'service_id')
    #    action = ['export_as_csv']
    
    class Media:
        js = ('dropdown/js/base.js',)




admin.site.register([
                     Account,
                     HonoraryCertificate,
                     Library,
                     IFG,
                     Travel,
                     Email,
                     List,
                     Literature,
                     ])
